==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/NativeUIAbsolutePanel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIAbsolutePanel = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIAbsolutePanel, _super);
    function NativeUIAbsolutePanel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIAbsolutePanel.prototype.get_c = function () {
        return 9;
    };
    Object.defineProperty(NativeUIAbsolutePanel.prototype, "az", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    NativeUIAbsolutePanel.prototype.a2 = function (a, b) {
        this.az.setX(this.u, a, b);
    };
    NativeUIAbsolutePanel.prototype.a3 = function (a, b) {
        this.az.setY(this.u, a, b);
    };
    NativeUIAbsolutePanel.prototype.a0 = function (a, b) {
        return this.az.getX(this.u, a);
    };
    NativeUIAbsolutePanel.prototype.a1 = function (a, b) {
        return this.az.getY(this.u, a);
    };
    NativeUIAbsolutePanel.$t = markType(NativeUIAbsolutePanel, 'NativeUIAbsolutePanel', NativeUIContainer.$);
    return NativeUIAbsolutePanel;
}(NativeUIContainer));
export { NativeUIAbsolutePanel };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/NativeUIAbsolutePanel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIAbsolutePanel = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIAbsolutePanel, _super);
    function NativeUIAbsolutePanel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIAbsolutePanel.prototype.get_e = function () {
        return 9;
    };
    Object.defineProperty(NativeUIAbsolutePanel.prototype, "a5", {
        get: function () {
            return this.d;
        },
        enumerable: true,
        configurable: true
    });
    NativeUIAbsolutePanel.prototype.a8 = function (a, b) {
        this.a5.setX(this.w, a, b);
    };
    NativeUIAbsolutePanel.prototype.a9 = function (a, b) {
        this.a5.setY(this.w, a, b);
    };
    NativeUIAbsolutePanel.prototype.a6 = function (a, b) {
        return this.a5.getX(this.w, a);
    };
    NativeUIAbsolutePanel.prototype.a7 = function (a, b) {
        return this.a5.getY(this.w, a);
    };
    NativeUIAbsolutePanel.$t = markType(NativeUIAbsolutePanel, 'NativeUIAbsolutePanel', NativeUIContainer.$);
    return NativeUIAbsolutePanel;
}(NativeUIContainer));
export { NativeUIAbsolutePanel };
